@@ -2,7 +2,7 @@ from django import forms
 from django.core.exceptions import ValidationError
 from django.db.models.base import Model
 from django.forms.fields import FileField
-from django.forms.forms import BoundField
+from django.forms.boundfield import BoundField
 
 from .fields import *
 from .models import *
